==> owncloud-10.0.7.tgz: owncloud/apps/federatedfilesharing/l10n/ast.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartíu federáu",
    "Invalid Federated Cloud ID" : "Inválidu ID de Ñube Federada",
    "Sharing %s failed, because this item is already shared with %s" : "Compartir %s falló, porque esti elementu yá ta compartiéndose con %s",
    "Not allowed to create a federated share with the same user" : "Nun s'almite crear un recursu compartíu federáu col mesmu usuariu",
    "File is already shared with %s" : "El ficheru yá ta compartíu con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Compartir %s falló, nun pudo atopase %s, pue qu'el servidor nun seya anguaño algamable.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Recibisti \"/%3$s\" como compartición remota dende %1$s (en nome de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Recibisti \"/%3$s\" como compatición remota dende %1$s",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparte conmigo a través del mio ID Nube Federada #ownCloud, consulta %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Comparte conmigo a través del mio ID Nube Federada #ownCloud",
    "Federated Cloud Sharing" : "Nube Compartida Federada",
    "Open documentation" : "Abrir documentación",
    "Allow users on this server to send shares to other servers" : "Permitir a los usuarios d'esti sirvidor compartir con otros sirvidores",
    "Allow users on this server to receive shares from other servers" : "Permitir a los usuarios d'esti sirvidor recibir comparticiones dende otros sirvidores",
    "Federated Cloud" : "Ñube Federada",
    "Your Federated Cloud ID:" : "El to ID de Ñube Federada",
    "Share it:" : "Compártilo:",
    "Add to your website" : "Amesta al to sitiu web",
    "Share with me via ownCloud" : "Comparte conmigo vía ownCloud",
    "HTML Code:" : "Códigu HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/ast.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartíu federáu",
    "Invalid Federated Cloud ID" : "Inválidu ID de Ñube Federada",
    "Sharing %s failed, because this item is already shared with %s" : "Compartir %s falló, porque esti elementu yá ta compartiéndose con %s",
    "Not allowed to create a federated share with the same user" : "Nun s'almite crear un recursu compartíu federáu col mesmu usuariu",
    "File is already shared with %s" : "El ficheru yá ta compartíu con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Compartir %s falló, nun pudo atopase %s, pue qu'el servidor nun seya anguaño algamable.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Recibisti \"/%3$s\" como compartición remota dende %1$s (en nome de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Recibisti \"/%3$s\" como compatición remota dende %1$s",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparte conmigo a través del mio ID Nube Federada #ownCloud, consulta %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Comparte conmigo a través del mio ID Nube Federada #ownCloud",
    "Federated Cloud Sharing" : "Nube Compartida Federada",
    "Open documentation" : "Abrir documentación",
    "Allow users on this server to send shares to other servers" : "Permitir a los usuarios d'esti sirvidor compartir con otros sirvidores",
    "Allow users on this server to receive shares from other servers" : "Permitir a los usuarios d'esti sirvidor recibir comparticiones dende otros sirvidores",
    "Federated Cloud" : "Ñube Federada",
    "Your Federated Cloud ID:" : "El to ID de Ñube Federada",
    "Share it:" : "Compártilo:",
    "Add to your website" : "Amesta al to sitiu web",
    "Share with me via ownCloud" : "Comparte conmigo vía ownCloud",
    "HTML Code:" : "Códigu HTML:",
    "Add to your ownCloud" : "Amestar al to ownCloud"
},
"nplurals=2; plural=(n != 1);");
